==> quarkus-core-deployment-2.11.3.Final-sources.jar: io/quarkus/deployment/builditem/nativeimage/JPMSExportBuildItem.java <==
package io.quarkus.deployment.builditem.nativeimage;

import java.util.Objects;

import io.quarkus.builder.item.MultiBuildItem;
import io.quarkus.deployment.pkg.steps.GraalVM;

/**
 * A build item that indicates that a Java package should be exported using
 * '-J--add-exports' option to become visible to native-image
 */
public final class JPMSExportBuildItem extends MultiBuildItem {
    private final String moduleName;
    private final String packageName;
    private final GraalVM.Version exportAfter;

    public JPMSExportBuildItem(String moduleName, String packageName) {
        this.moduleName = moduleName;
        this.packageName = packageName;
        this.exportAfter = GraalVM.Version.MINIMUM;
    }

    public JPMSExportBuildItem(String moduleName, String packageName, GraalVM.Version exportAfter) {
        this.moduleName = moduleName;
        this.packageName = packageName;
        this.exportAfter = exportAfter;
    }

    public String getPackage() {
        return packageName;
    }

    public String getModule() {
        return moduleName;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        JPMSExportBuildItem that = (JPMSExportBuildItem) o;
        return moduleName.equals(that.moduleName) && packageName.equals(that.packageName);
    }

    @Override
    public int hashCode() {
        return Objects.hash(moduleName, packageName);
    }

    public GraalVM.Version getExportAfter() {
        return exportAfter;
    }
}

==> quarkus-core-deployment-2.13.0.Final-sources.jar: io/quarkus/deployment/builditem/nativeimage/JPMSExportBuildItem.java <==
package io.quarkus.deployment.builditem.nativeimage;

import java.util.Objects;

import io.quarkus.builder.item.MultiBuildItem;
import io.quarkus.deployment.pkg.steps.GraalVM;

/**
 * A build item that indicates that a Java package should be exported using
 * '-J--add-exports' option to become visible to native-image
 */
public final class JPMSExportBuildItem extends MultiBuildItem {
    private final String moduleName;
    private final String packageName;
    private final GraalVM.Version exportAfter;
    private final GraalVM.Version exportBefore;

    public JPMSExportBuildItem(String moduleName, String packageName) {
        this(moduleName, packageName, GraalVM.Version.MINIMUM, null);
    }

    public JPMSExportBuildItem(String moduleName, String packageName, GraalVM.Version exportAfter) {
        this(moduleName, packageName, exportAfter, null);
    }

    public JPMSExportBuildItem(String moduleName, String packageName, GraalVM.Version exportAfter,
            GraalVM.Version exportBefore) {
        this.moduleName = moduleName;
        this.packageName = packageName;
        this.exportAfter = exportAfter;
        this.exportBefore = exportBefore;
    }

    public String getPackage() {
        return packageName;
    }

    public String getModule() {
        return moduleName;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        JPMSExportBuildItem that = (JPMSExportBuildItem) o;
        return moduleName.equals(that.moduleName) && packageName.equals(that.packageName);
    }

    @Override
    public int hashCode() {
        return Objects.hash(moduleName, packageName);
    }

    public GraalVM.Version getExportAfter() {
        return exportAfter;
    }

    public GraalVM.Version getExportBefore() {
        return exportBefore;
    }
}
